@@ -18,21 +18,21 @@ class CMSContactPlusPlugin(CMSPluginBase):
     def render(self, context, instance, placeholder):
         request = context['request']
         if request.method == "POST":
-            form = ContactFormPlus(contactFormInstance=instance, data=request.POST)
+            form = ContactFormPlus(contactFormInstance=instance, request=request, data=request.POST)
             if form.is_valid():
                 form.send(instance.reciepient_email, request)
                 context.update({
-                        'contact': instance,
+                    'contact': instance,
                 })
                 return context
             else:
                 context.update({
-                        'contact': instance,
-                        'form': form,
+                    'contact': instance,
+                    'form': form,
                         
                 })
         else:
-            form = ContactFormPlus(contactFormInstance=instance) 
+            form = ContactFormPlus(contactFormInstance=instance, request=request) 
             context.update({
                     'contact': instance,
                     'form': form,
