@@ -61,7 +61,14 @@ class ContactFormPlus(forms.Form):
                             initial = lInitial, #NOTE: This overwrites extraField.initial! 
                             widget=forms.HiddenInput, 
                             required=False) 
-                            
+                elif extraField.fieldType == 'auto_GET_parameter':
+                    lInitial = "Key/value parameter not available."
+                    if request:
+                        lInitial = request.GET.get(slugify(extraField.label), 'n/a')
+                    self.fields[slugify(extraField.label)] = forms.CharField(label=extraField.label, 
+                            initial = lInitial, #NOTE: This overwrites extraField.initial! 
+                            widget=forms.HiddenInput, 
+                            required=False)
                 
                 
                 
